mysql.exceptions.client.No_Prepare_Stmt

Package mysql :: Package exceptions :: Module client :: Class No_Prepare_Stmt |
[hide private]
[frames] | no frames]

# Class No_Prepare_Stmt

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  No_Prepare_Stmt

Statement not prepared.

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`